@@ -15,24 +15,27 @@
  */
 package org.mybatis.spring;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
 
+import org.apache.ibatis.reflection.factory.DefaultObjectFactory;
+import org.apache.ibatis.reflection.factory.ObjectFactory;
+import org.apache.ibatis.reflection.wrapper.DefaultObjectWrapperFactory;
+import org.apache.ibatis.reflection.wrapper.ObjectWrapperFactory;
 import org.apache.ibatis.session.SqlSessionFactory;
 import org.apache.ibatis.transaction.TransactionFactory;
 import org.apache.ibatis.transaction.jdbc.JdbcTransactionFactory;
 import org.apache.ibatis.type.TypeAliasRegistry;
+import org.apache.ibatis.type.TypeException;
 import org.apache.ibatis.type.TypeHandler;
 import org.apache.ibatis.type.TypeHandlerRegistry;
 import org.junit.Test;
 import org.mybatis.spring.transaction.SpringManagedTransactionFactory;
 import org.mybatis.spring.type.DummyTypeAlias;
 import org.mybatis.spring.type.DummyTypeHandler;
+import org.mybatis.spring.type.SuperType;
 import org.springframework.core.io.ClassPathResource;
 import org.springframework.core.io.Resource;
 
@@ -44,6 +47,9 @@ import com.mockrunner.mock.jdbc.MockDataSource;
  */
 public final class SqlSessionFactoryBeanTest {
 
+  private static final class TestObjectFactory extends DefaultObjectFactory {}
+  private static final class TestObjectWrapperFactory extends DefaultObjectWrapperFactory {}
+
   private static MockDataSource dataSource = new MockDataSource();
 
   private SqlSessionFactoryBean factoryBean;
@@ -138,7 +144,7 @@ public final class SqlSessionFactoryBeanTest {
     // for each statement in the xml file: org.mybatis.spring.TestMapper.xxx & xxx
     assertEquals(8, factory.getConfiguration().getMappedStatementNames().size());
 
-    assertEquals(4, factory.getConfiguration().getResultMapNames().size());
+    assertEquals(0, factory.getConfiguration().getResultMapNames().size());
     assertEquals(0, factory.getConfiguration().getParameterMapNames().size());
   }
 
@@ -205,6 +211,33 @@ public final class SqlSessionFactoryBeanTest {
     TypeAliasRegistry typeAliasRegistry = factoryBean.getObject().getConfiguration().getTypeAliasRegistry();
     typeAliasRegistry.resolveAlias("testAlias");
     typeAliasRegistry.resolveAlias("testAlias2");
+    typeAliasRegistry.resolveAlias("dummyTypeHandler");
+    typeAliasRegistry.resolveAlias("superType");
+  }
+
+  @Test
+  public void testSearchATypeAliasPackageWithSuperType() throws Exception {
+    setupFactoryBean();
+    factoryBean.setTypeAliasesSuperType(SuperType.class);
+    factoryBean.setTypeAliasesPackage("org/mybatis/spring/type");
+
+    TypeAliasRegistry typeAliasRegistry = factoryBean.getObject().getConfiguration().getTypeAliasRegistry();
+    typeAliasRegistry.resolveAlias("testAlias2");
+    typeAliasRegistry.resolveAlias("superType");
+
+    try {
+        typeAliasRegistry.resolveAlias("testAlias");
+        fail();
+    } catch (TypeException e) {
+        // expected
+    }
+
+    try {
+        typeAliasRegistry.resolveAlias("dummyTypeHandler");
+        fail();
+    } catch (TypeException e) {
+        // expected
+    }
   }
 
   @Test
@@ -217,6 +250,24 @@ public final class SqlSessionFactoryBeanTest {
     assertTrue(typeHandlerRegistry.hasTypeHandler(BigDecimal.class));
   }
 
+  @Test
+  public void testSetObjectFactory() throws Exception {
+    setupFactoryBean();
+    factoryBean.setObjectFactory(new TestObjectFactory());
+
+    ObjectFactory objectFactory = factoryBean.getObject().getConfiguration().getObjectFactory();
+    assertTrue(objectFactory instanceof TestObjectFactory);
+  }
+
+  @Test
+  public void testSetObjectWrapperFactory() throws Exception {
+    setupFactoryBean();
+    factoryBean.setObjectWrapperFactory(new TestObjectWrapperFactory());
+
+    ObjectWrapperFactory objectWrapperFactory = factoryBean.getObject().getConfiguration().getObjectWrapperFactory();
+    assertTrue(objectWrapperFactory instanceof TestObjectWrapperFactory);
+  }
+
   private void assertDefaultConfig(SqlSessionFactory factory) {
     assertConfig(factory, SqlSessionFactoryBean.class.getSimpleName(),
         org.mybatis.spring.transaction.SpringManagedTransactionFactory.class);
