@@ -1,5 +1,5 @@
 /*
- *    Copyright 2010 The myBatis Team
+ *    Copyright 2010-2012 The MyBatis Team
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -20,4 +20,5 @@ package org.mybatis.spring.mapper;
  */
 // child class for MapperScannerPostProcessor tests
 // ensures classes are not loaded as MapperFactoryBeans
-public class MapperClass {}
+public class MapperClass {
+}
