@@ -27,10 +27,13 @@ import org.junit.Before;
 import org.junit.Test;
 import org.mybatis.spring.SqlSessionFactoryBean;
 import org.mybatis.spring.SqlSessionTemplate;
+import org.mybatis.spring.mapper.child.MapperChildInterface;
 import org.springframework.beans.factory.NoSuchBeanDefinitionException;
+import org.springframework.beans.factory.config.BeanDefinition;
 import org.springframework.beans.factory.config.ConstructorArgumentValues;
 import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
 import org.springframework.beans.factory.config.RuntimeBeanReference;
+import org.springframework.beans.factory.support.BeanDefinitionRegistry;
 import org.springframework.beans.factory.support.GenericBeanDefinition;
 import org.springframework.context.support.GenericApplicationContext;
 import org.springframework.stereotype.Component;
@@ -77,10 +80,7 @@ public final class MapperScannerConfigurerTest {
     // no method interfaces should be ignored too
     assertBeanNotLoaded("package-info");
     //        assertBeanNotLoaded("annotatedMapperZeroMethods"); // as of 1.1.0 mappers with no methods are loaded
-  }
-
-  @After
-  public void destroyContext() {
+    
     applicationContext.destroy();
   }
 
@@ -95,6 +95,24 @@ public final class MapperScannerConfigurerTest {
     applicationContext.getBean("annotatedMapper");
   }
 
+  @Test
+  public void testNameGenerator() {
+    GenericBeanDefinition definition = new GenericBeanDefinition();
+    definition.setBeanClass(BeanNameGenerator.class);
+    applicationContext.registerBeanDefinition("beanNameGenerator", definition);
+
+    applicationContext.getBeanDefinition("mapperScanner").getPropertyValues().add(
+        "nameGenerator", new RuntimeBeanReference("beanNameGenerator"));
+
+    startContext();
+
+    // only child inferfaces should be loaded and named with its class name
+    applicationContext.getBean(MapperInterface.class.getName());
+    applicationContext.getBean(MapperSubinterface.class.getName());
+    applicationContext.getBean(MapperChildInterface.class.getName());
+    applicationContext.getBean(AnnotatedMapper.class.getName());
+  }
+
   @Test
   public void testMarkerInterfaceScan() {
     applicationContext.getBeanDefinition("mapperScanner").getPropertyValues().add(
@@ -207,6 +225,7 @@ public final class MapperScannerConfigurerTest {
     // use a property placeholder for basePackage
     definition.getPropertyValues().removePropertyValue("basePackage");
     definition.getPropertyValues().add("basePackage", "${basePackageProperty}");
+    definition.getPropertyValues().add("processPropertyPlaceHolders", true);
 
     // also use a property placeholder for an SqlSessionFactory property
     // to make sure the configLocation was setup correctly and MapperScanner did not change
@@ -250,4 +269,13 @@ public final class MapperScannerConfigurerTest {
       // success
     }
   }
+  
+  public static class BeanNameGenerator implements org.springframework.beans.factory.support.BeanNameGenerator {
+
+    public String generateBeanName(BeanDefinition beanDefinition, BeanDefinitionRegistry definitionRegistry) {
+      return beanDefinition.getBeanClassName();
+    }
+
+  }
+
 }
