@@ -23,6 +23,6 @@ import org.springframework.test.context.ContextConfiguration;
  * 
  * @version $Id$
  */
-@ContextConfiguration(locations = { "classpath:org/mybatis/spring/sample/applicationContext-mapper.xml" })
+@ContextConfiguration(locations = { "classpath:org/mybatis/spring/sample/config/applicationContext-mapper.xml" })
 public class SampleMapperTest extends AbstractSampleTest {
 }
