@@ -19,7 +19,6 @@ import static org.junit.Assert.assertEquals;
 
 import java.sql.SQLException;
 
-import org.apache.ibatis.session.SqlSessionFactory;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
@@ -27,8 +26,6 @@ import org.mybatis.spring.AbstractMyBatisSpringTest;
 import org.mybatis.spring.SqlSessionFactoryBean;
 import org.mybatis.spring.SqlSessionTemplate;
 import org.springframework.beans.factory.BeanCreationException;
-import org.springframework.beans.factory.config.ConstructorArgumentValues;
-import org.springframework.beans.factory.config.RuntimeBeanReference;
 import org.springframework.beans.factory.support.GenericBeanDefinition;
 import org.springframework.context.annotation.AnnotationConfigUtils;
 import org.springframework.context.support.GenericApplicationContext;
@@ -84,49 +81,12 @@ public final class SqlSessionDaoSupportTest extends AbstractMyBatisSpringTest {
     sqlSessionDaoSupport.afterPropertiesSet();
   }
 
-  @Test
-  public void testAutowireSqlSessionTemplate() {
-    setupContext();
-
-    setupSqlSessionTemplate("template");
-
-    startContext();
-
-    assertEquals("should store the Template", applicationContext.getBean(SqlSessionTemplate.class),
-        sqlSessionDaoSupport.getSqlSession());
-  }
-
-  @Test
-  public void testAutowireSqlSessionFactory() {
-    setupContext();
-    setupSqlSessionFactory("factory1");
-
-    startContext();
-
-    assertEquals("should store the Factory", applicationContext.getBean(SqlSessionFactory.class),
-        ((SqlSessionTemplate) sqlSessionDaoSupport.getSqlSession()).getSqlSessionFactory());
-
-  }
-
   @Test(expected = org.springframework.beans.factory.BeanCreationException.class)
   public void testAutowireWithNoFactoryOrSession() {
     setupContext();
     startContext();
   }
 
-  @Test
-  public void testAutowireWithBothFactoryAndTemplate() {
-    setupContext();
-
-    setupSqlSessionFactory("factory");
-    setupSqlSessionTemplate("template");
-
-    startContext();
-
-    assertEquals("should ignore the Factory", applicationContext.getBean(SqlSessionTemplate.class),
-        sqlSessionDaoSupport.getSqlSession());
-  }
-
   @Test(expected = BeanCreationException.class)
   public void testAutowireWithTwoFactories() {
     setupContext();
@@ -137,16 +97,6 @@ public final class SqlSessionDaoSupportTest extends AbstractMyBatisSpringTest {
     startContext();
   }
 
-  @Test(expected = BeanCreationException.class)
-  public void testAutowireWithTwoTemplates() {
-    setupContext();
-
-    setupSqlSessionTemplate("template1");
-    setupSqlSessionTemplate("template2");
-
-    startContext();
-  }
-
   private void setupContext() {
     applicationContext = new GenericApplicationContext();
 
@@ -173,17 +123,6 @@ public final class SqlSessionDaoSupportTest extends AbstractMyBatisSpringTest {
     applicationContext.registerBeanDefinition(name, definition);
   }
 
-  private void setupSqlSessionTemplate(String name) {
-    setupSqlSessionFactory("sqlSessionFactory");
-
-    GenericBeanDefinition definition = new GenericBeanDefinition();
-    definition.setBeanClass(SqlSessionTemplate.class);
-    ConstructorArgumentValues constructorArgs = new ConstructorArgumentValues();
-    constructorArgs.addGenericArgumentValue(new RuntimeBeanReference("sqlSessionFactory"));
-    definition.setConstructorArgumentValues(constructorArgs);
-    applicationContext.registerBeanDefinition(name, definition);
-  }
-
   private static final class MockSqlSessionDao extends SqlSessionDaoSupport {
   }
 }
